package com.ruoyi.frequency.mallorderstatus.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.enums.mallorder.MallOrderStatusEnums;
import com.ruoyi.frequency.mallorder.entity.MallOrder;
import com.ruoyi.frequency.mallorderstatus.entity.MallOrderStatus;

import java.util.List;

/**
 * 订单流程Service接口
 *
 * @author liwenlong
 * @date 2024-01-25
 */
public interface MallOrderStatusService extends IService<MallOrderStatus>
{
    /**
     * 查询订单流程
     *
     * @param id 订单流程主键
     * @return 订单流程
     */
    public MallOrderStatus selectMallOrderStatusById(Long id);

    /**
     * 查询订单流程列表
     *
     * @param mallOrderStatus 订单流程
     * @return 订单流程集合
     */
    public List<MallOrderStatus> selectMallOrderStatusList(MallOrderStatus mallOrderStatus);

    /**
     * 新增订单流程
     *
     * @param mallOrderStatus 订单流程
     * @return 结果
     */
    public int insertMallOrderStatus(MallOrderStatus mallOrderStatus);

    /**
     * 修改订单流程
     *
     * @param mallOrderStatus 订单流程
     * @return 结果
     */
    public int updateMallOrderStatus(MallOrderStatus mallOrderStatus);

    /**
     * 批量删除订单流程
     *
     * @param ids 需要删除的订单流程主键集合
     * @return 结果
     */
    public int deleteMallOrderStatusByIds(Long[] ids,Integer delFlag);

    /**
     * 记录订单流程状态
     * @param order
     * @param mallOrderStatusEnums
     */
    void recordOrderStatus(MallOrder order, MallOrderStatusEnums mallOrderStatusEnums);
}
